@@ -14,17 +14,71 @@ JavaScript::QuickJS - Run JavaScript via L<QuickJS|https://bellard.org/quickjs>
 Quick and dirty …
 
     my $val = JavaScript::QuickJS->new()->eval( q<
-        console.log("Hello, Perl!");
+        let foo = "bar";
         [ "The", "last", "value", "is", "returned." ];
     > );
 
 =head1 DESCRIPTION
 
-This library embeds Fabrice Bellard’s QuickJS
-engine into Perl. You can thus run JavaScript directly in your Perl programs.
+This library embeds Fabrice Bellard’s L<QuickJS|https://bellard.org/quickjs>
+engine into a Perl XS module. You can thus run JavaScript
+(L<ES2020|https://tc39.github.io/ecma262/>) specification) directly in your
+Perl programs.
 
-This distribution includes QuickJS and builds it as part of building this
-module.
+This distribution includes all needed C code; unlike with most XS modules
+that interface with C libraries, you don’t need QuickJS pre-installed on
+your system.
+
+=cut
+
+# ----------------------------------------------------------------------
+
+use XSLoader;
+
+our $VERSION = '0.03_01';
+
+XSLoader::load( __PACKAGE__, $VERSION );
+
+# ----------------------------------------------------------------------
+
+=head1 METHODS
+
+=head2 $obj = I<CLASS>->new()
+
+Instantiates I<CLASS>.
+
+=head2 $obj = I<OBJ>->set_globals( NAME1 => VALUE1, .. )
+
+Sets 1 or more globals in I<OBJ>. See below for details on type conversions
+from Perl to JavaScript.
+
+=head2 $obj = I<OBJ>->helpers()
+
+Defines QuickJS’s “helpers”, e.g., C<console.log>.
+
+=head2 $obj = I<OBJ>->std()
+
+Enables (but does I<not> import) QuickJS’s C<std> module.
+
+=head2 $obj = I<OBJ>->os()
+
+Like C<std()> but for QuickJS’s C<os> module.
+
+=head2 $VALUE = I<OBJ>->eval( $JS_CODE )
+
+Comparable to running C<qjs -e '...'>. Returns the last value from $JS_CODE;
+see below for details on type conversions from JavaScript to Perl.
+
+Untrapped exceptions in JavaScript will be rethrown as Perl exceptions.
+
+=head2 I<OBJ>->eval_module( $JS_CODE )
+
+Runs $JS_CODE as a module, which enables ES6 module syntax.
+Note that no values can be returned directly in this mode of execution.
+
+=cut
+
+# ----------------------------------------------------------------------
 
 =head1 TYPE CONVERSION: JAVASCRIPT → PERL
 
@@ -77,6 +131,30 @@ primitives.
 
 =back
 
+=head1 NUMERIC PRECISION
+
+Note the following if you expect to deal with “large” numbers:
+
+=over
+
+=item * JavaScript’s numeric-precision limits apply. (cf.
+L<Number.MAX_SAFE_INTEGER|https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MAX_SAFE_INTEGER>.)
+
+=item * Perl’s stringification of numbers may be I<less> precise than
+JavaScript’s storage of those numbers, or even than Perl’s own storage.
+For example, in Perl 5.34 C<print 1000000000000001.0> prints C<1e+15>.
+
+To counteract this loss of precision, add 0 to Perl’s numeric scalars
+(e.g., C<print 0 + 1000000000000001.0>); this will encourage Perl to store
+numbers as integers when possible, which fixes the precision problem.
+
+=item * Long-double and quad-math perls may lose precision when converting
+numbers to/from JavaScript. To see if this is a problem for you, run
+C<perl -V>, and see if the compile-time options mention long doubles or
+quad math.
+
+=back
+
 =head1 PLATFORM NOTES
 
 Due to QuickJS limitations, Linux & macOS are the only platforms known
@@ -86,48 +164,27 @@ details.
 
 Pull requests to improve portability are welcome!
 
-=cut
+=head1 SEE ALSO
 
-# ----------------------------------------------------------------------
+Other JavaScript modules on CPAN include:
 
-use XSLoader;
+=over
 
-our $VERSION = '0.01_02';
+=item * L<JavaScript::Duktape::XS> and L<JavaScript::Duktape> make the
+L<Duktape|https://duktape.org> library available to Perl. They’re similar to
+this library, but Duktape itself (as of this writing) lacks support for
+several JavaScript constructs that QuickJS supports. (It’s also slower.)
 
-XSLoader::load( __PACKAGE__, $VERSION );
+=item * L<JavaScript::V8> and L<JavaScript::V8::XS> expose Google’s
+L<V8|https://v8.dev> library to Perl. Neither seems to support current
+V8 versions.
 
-# ----------------------------------------------------------------------
+=item * L<JE> is a pure-Perl (!) JavaScript engine.
 
-=head1 METHODS
+=item * L<JavaScript> and L<JavaScript::Lite> expose Mozilla’s
+L<SpiderMonkey|https://spidermonkey.dev/> engine to Perl.
 
-For now only a static interface is provided:
-
-=head2 $obj = I<CLASS>->new()
-
-Instantiates I<CLASS>.
-
-=head2 $obj = I<OBJ>->std()
-
-Enables (but does I<not> import) QuickJS’s C<std> module.
-
-=head2 $obj = I<OBJ>->os()
-
-Like C<std()> but for QuickJS’s C<os> module.
-
-=head2 $obj = I<OBJ>->helpers()
-
-Defines QuickJS’s “helpers”, e.g., C<console.log>.
-
-=head2 $VALUE = eval( $JS_CODE )
-
-Comparable to running C<qjs -e '...'>. Returns the last value from $JS_CODE.
-
-Untrapped exception in JavaScript will be rethrown as Perl exceptions.
-
-=head2 eval_module( $JS_CODE )
-
-Runs $JS_CODE as a module, which enables ES6 module syntax.
-Note that no values can be returned directly in this mode of execution.
+=back
 
 =head1 LICENSE & COPYRIGHT
 
